import sys
import math


def read_input():
    n = int(sys.stdin.readline().strip())
    points = [tuple(map(int, sys.stdin.readline().strip().split())) for _ in range(n)]
    return n, points


def calculate_distances(points):
    n = len(points)
    dist = [[0] * n for _ in range(n)]
    for i in range(n):
        for j in range(n):
            if i != j:
                dist[i][j] = math.sqrt((points[i][0] - points[j][0]) ** 2 + (points[i][1] - points[j][1]) ** 2)
    return dist


def tsp(n, dist):
    # DP[mask][i] - минимальное расстояние для посещения всех узлов в mask, заканчивая в узле i
    dp = [[float('inf')] * n for _ in range(1 << n)]

    # Начинаем с первого узла
    for i in range(n):
        dp[1 << i][i] = 0

    # Заполнение DP таблицы
    for mask in range(1 << n):
        for u in range(n):
            if mask & (1 << u):
                # Если u включен в маску
                for v in range(n):
                    if mask & (1 << v) == 0:
                        # Если v не включен в маску
                        new_mask = mask | (1 << v)
                        dp[new_mask][v] = min(dp[new_mask][v], dp[mask][u] + dist[u][v])

    # Получаем минимальный путь, возвращаясь к начальной точке
    answer = float('inf')
    for i in range(n):
        answer = min(answer, dp[(1 << n) - 1][i])

    return answer


def main():
    n, points = read_input()
    dist = calculate_distances(points)
    result = tsp(n, dist)
    print(f"{result:.9f}")


if __name__ == "__main__":
    main()
